@@ -4,7 +4,7 @@ TSRCS =  tObstack.cc tString.cc tInteger.cc tRational.cc \
  tBitSet.cc tBitString.cc tRandom.cc tList.cc tPlex.cc \
  tLList.cc tVec.cc tStack.cc tQueue.cc tDeque.cc tPQ.cc tSet.cc  tBag.cc \
  tMap.cc tFix.cc tFix16.cc tFix24.cc \
- tGetOpt.cc \
+ tCurses.cc tGetOpt.cc \
  tiLList.cc
 EOF
 
@@ -14,7 +14,7 @@ TESTS1="tStack tQueue tDeque tPQ tSet tBag tMap tList tPlex tLList tVec"
 
 cat <<EOF
 # executables
-TOUTS =  test_h ${TESTS0} ${TESTS1} tiLList tGetOpt
+TOUTS =  test_h \$(TCURSES) ${TESTS0} ${TESTS1} tiLList tGetOpt
 
 EOF
 
@@ -91,17 +91,18 @@ LIBTEST=libtest.a
 
 # Comment this out if your compiler doesn't handle templates:
 CHECK_TEMPLATES=check-templates
-CHECKS=check-tObstack check-tString check-tInteger \
+
+tests checktests: clean_tests test_h $(TCURSES) \
+  check-tObstack check-tString check-tInteger \
   check-tRational check-tBitSet check-tBitString \
   check-tFix check-tFix16 check-tFix24 check-tGetOpt \
   check-tList check-tPlex check-tLList check-tVec \
   check-tStack check-tQueue check-tDeque check-tPQ \
   check-tSet check-tBag check-tMap $(CHECK_TEMPLATES)
-
-tests checktests: test_h $(CHECKS)
 	./test_h
-
-$(CHECKS): clean_tests
+	@if [ x$(TCURSES) = xtCurses ]; then \
+		echo "(Must run tCurses manually from tty)"; \
+	else true; fi
 
 check-templates: check-tiLList
 
@@ -114,7 +115,9 @@ make-tests: $(TOUTS)
 
 test_h: test_h.o
 	$(CXX) $(LDFLAGS) test_h.o -o $@ $(LIBS) -lm
+	
 
+	
 $(LIBTEST): $(LHDRS) $(LOBJS)
 	rm -f $(LIBTEST)
 	$(AR) r $(LIBTEST) $(LOBJS)
@@ -131,8 +134,9 @@ LIB_FOR_tRandom=-lm
 LIB_FOR_tFix=-lm
 LIB_FOR_tFix16=-lm
 LIB_FOR_tFix24=-lm
+LIB_FOR_tCurses="-lcurses -ltermcap"
 
-for TEST in $TESTS0 tiLList tGetOpt; do
+for TEST in $TESTS0 tiLList tCurses tGetOpt; do
   echo "${TEST}: ${TEST}.o"
   echo '	$(CXX) $(LDFLAGS)' "${TEST}.o" '-o $@ $(LIBS)' \
 	`eval echo '$LIB_FOR_'$TEST`
