@@ -35,6 +35,12 @@ the executable file might be covered by the GNU General Public License. */
 #include <string.h>
 #include <limits.h>
 #include "floatio.h"
+#ifdef __linux__
+#include <printf.h>
+extern "C" int __printf_fp __P ((FILE *,
+				const struct printf_info *,
+				const void **const));
+#endif
 
 #define	BUF		(MAXEXP+MAXFRACT+1)	/* + decimal point */
 
@@ -321,7 +327,11 @@ READ_INT(bool)
 istream& istream::operator>>(long double& x)
 {
     if (ipfx0())
+#ifdef __linux__
+	scan("%Lg", &x);
+#else
 	scan("%lg", &x);
+#endif
     return *this;
 }
 
@@ -551,6 +561,48 @@ ostream& ostream::operator<<(unsigned long long n)
 }
 #endif /*__GNUC__*/
 
+#ifdef __linux__
+ostream& ostream::operator<<(long double n)
+{
+    if (opfx()) {
+	int format_char;
+	if ((flags() & ios::floatfield) == ios::fixed)
+	    format_char = 'f';
+	else if ((flags() & ios::floatfield) == ios::scientific)
+	    format_char = flags() & ios::uppercase ? 'E' : 'e';
+	else
+	    format_char = flags() & ios::uppercase ? 'G' : 'g';
+
+	int prec = precision();
+	if (prec <= 0 && !(flags() & ios::fixed))
+	  prec = 6; /* default */
+
+	// Do actual conversion.
+	struct printf_info info;
+
+	info.prec = prec;
+	info.width = width (0);
+	info.spec = format_char;
+	info.is_long_double = 1;
+	info.is_short = 0;
+	info.is_long = 0;
+	info.alt = flags() & ios::showpoint;
+	info.space = 0;
+	info.left = flags() & ios::left;
+	info.showsign = flags() & ios::showpos;
+	info.group = 0;
+	info.pad = fill();
+
+	_IO_va_list p = (_IO_va_list) &n;
+
+	if (__printf_fp (rdbuf(), &info, &p) < 0)
+	    set(ios::badbit|ios::failbit); // ??
+	osfx();
+    }
+    return *this;
+}
+#endif
+
 ostream& ostream::operator<<(double n)
 {
     if (opfx()) {
@@ -570,6 +622,27 @@ ostream& ostream::operator<<(double n)
 	  prec = 6; /* default */
 
 	// Do actual conversion.
+#ifdef __linux__
+	struct printf_info info;
+
+	info.prec = prec;
+	info.width = width (0);
+	info.spec = format_char;
+	info.is_long_double = 0;
+	info.is_short = 0;
+	info.is_long = 0;
+	info.alt = flags() & ios::showpoint;
+	info.space = 0;
+	info.left = flags() & ios::left;
+	info.showsign = flags() & ios::showpos;
+	info.group = 0;
+	info.pad = fill();
+
+	_IO_va_list p = (_IO_va_list) &n;
+
+	if (__printf_fp (rdbuf(), &info, &p) < 0)
+	    set(ios::badbit|ios::failbit); // ??
+#else
 #ifdef _IO_USE_DTOA
 	if (_IO_outfloat(n, rdbuf(), format_char, width(0),
 			 prec, flags(),
@@ -625,6 +698,7 @@ ostream& ostream::operator<<(double n)
 
 	if (pad_kind == (ios::fmtflags)ios::left) // Left adjustment
 	    for (i = padding; --i >= 0; ) sbuf->sputc(fill_char);
+#endif
 #endif
 	osfx();
     }
