@@ -13,8 +13,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU CC; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+along with this library; see the file COPYING.  If not, write to the Free
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 As a special exception, if you link this library with files
 compiled with a GNU compiler to produce an executable, this does not cause
@@ -26,14 +26,12 @@ the executable file might be covered by the GNU General Public License. */
 #include "strfile.h"
 
 int
-_IO_vsscanf (string, format, args)
-     const char *string;
-     const char *format;
-     _IO_va_list args;
+DEFUN(_IO_vsscanf, (string, format, args),
+      const char *string AND const char *format AND _IO_va_list args)
 {
   _IO_strfile sf;
   _IO_init((_IO_FILE*)&sf, 0);
-  ((_IO_FILE*)&sf)->_jumps = &_IO_str_jumps;
+  _IO_JUMPS((_IO_FILE*)&sf) = &_IO_str_jumps;
   _IO_str_init_static ((_IO_FILE*)&sf, (char*)string, 0, NULL);
   return _IO_vfscanf((_IO_FILE*)&sf, format, args, NULL);
 }
