@@ -70,7 +70,9 @@ the executable file might be covered by the GNU General Public License. */
 #ifndef __STDC__
 #define const
 #endif
+#ifndef __linux__
 #define _IO_USE_DTOA
+#endif
 #define _IO_UNIFIED_JUMPTABLES 1
 
 #if 0
@@ -141,6 +143,15 @@ the executable file might be covered by the GNU General Public License. */
 #define _IO_STDIO 040000
 #define _IO_DONT_CLOSE 0100000
 
+/* The reentrent version of the libio implementation needs a semaphore for
+   each _IO_FILE struture.  Because we don't know how the semaphore
+   will be implemented we try to be very general.  */
+struct _IO_lock_t {
+  void *ptr;
+  short int field1;
+  short int field2;
+};
+
 /* A streammarker remembers a position in a buffer. */
 
 struct _IO_jump_t;  struct _IO_FILE;
@@ -169,7 +180,6 @@ struct _IO_FILE {
 #define _IO_file_flags _flags
 
   /* The following pointers correspond to the C++ streambuf protocol. */
-  /* Note:  Tk uses the _IO_read_ptr and _IO_read_end fields directly. */
   char* _IO_read_ptr;	/* Current read pointer */
   char* _IO_read_end;	/* End of get area. */
   char* _IO_read_base;	/* Start of putback+get area. */
@@ -198,6 +208,8 @@ struct _IO_FILE {
   char _shortbuf[1];
   
   /*  char* _save_gptr;  char* _save_egptr; */
+
+  struct _IO_lock_t _IO_lock;
 };
 
 #ifndef __cplusplus
